@@ -37,4 +37,6 @@ class DetectLivingFaceRequest(RpcRequest):
 	def set_Taskss(self, Taskss):
 		for depth1 in range(len(Taskss)):
 			if Taskss[depth1].get('ImageURL') is not None:
-				self.add_body_params('Tasks.' + str(depth1 + 1) + '.ImageURL', Taskss[depth1].get('ImageURL'))
\ No newline at end of file
+				self.add_body_params('Tasks.' + str(depth1 + 1) + '.ImageURL', Taskss[depth1].get('ImageURL'))
+			if Taskss[depth1].get('ImageData') is not None:
+				self.add_body_params('Tasks.' + str(depth1 + 1) + '.ImageData', Taskss[depth1].get('ImageData'))
\ No newline at end of file
